"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.shouldServe = exports.build = exports.version = void 0;
const fs_1 = require("fs");
const path_1 = __importDefault(require("path"));
const build_utils_1 = require("@vercel/build-utils");
Object.defineProperty(exports, "shouldServe", { enumerable: true, get: function () { return build_utils_1.shouldServe; } });
const execa_1 = __importDefault(require("execa"));
const fast_glob_1 = __importDefault(require("fast-glob"));
const process_1 = __importDefault(require("process"));
const js_yaml_1 = __importDefault(require("js-yaml"));
const SDK_VERSION = ">=2.6.0 <3.0.0";
const RUNTIME_PKG = {
    git: {
        url: "git@github.com:frencojobs/vercel-dart.git",
        path: "dart",
    },
};
fs_1.chmodSync(path_1.default.join(__dirname, "build.sh"), 0o755);
async function readPubspec(directory, { name, sdk }) {
    const files = await fast_glob_1.default("pubspec.{yaml,yml}", {
        cwd: directory,
    });
    if (files.length == 0) {
        return `
    name: ${name}
    environment:
      sdk: ${sdk}
    `;
    }
    else {
        const data = await fs_1.promises.readFile(path_1.default.join(directory, files[0]), "utf-8");
        return data;
    }
}
function makePubspec(input) {
    var _a, _b;
    const data = (_a = js_yaml_1.default.load(input)) !== null && _a !== void 0 ? _a : {};
    return js_yaml_1.default.dump({
        ...data,
        dependencies: {
            ...((_b = data === null || data === void 0 ? void 0 : data.dependencies) !== null && _b !== void 0 ? _b : {}),
            vercel_dart: RUNTIME_PKG,
        },
    });
}
// Implementation taken from https://github.com/mike-engel/now-rust/blob/master/src/index.ts
async function gatherExtraFiles(globMatcher, entrypoint) {
    if (!globMatcher)
        return {};
    build_utils_1.debug("Gathering extra files");
    const entryDir = path_1.default.dirname(entrypoint);
    if (Array.isArray(globMatcher)) {
        const allMatches = await Promise.all(globMatcher.map((pattern) => build_utils_1.glob(pattern, entryDir)));
        return allMatches.reduce((acc, matches) => ({ ...acc, ...matches }), {});
    }
    return build_utils_1.glob(globMatcher, entryDir);
}
const version = 1;
exports.version = version;
async function build({ files, entrypoint, workPath, config = {}, meta = {}, }) {
    const { devCacheDir = path_1.default.join(workPath, ".vercel", "cache") } = meta;
    const distPath = path_1.default.join(devCacheDir, "dart", entrypoint);
    build_utils_1.debug("Writing `pubspec.yaml` file");
    const tmp = await build_utils_1.getWriteableDirectory();
    const pubspec = await readPubspec(path_1.default.dirname(entrypoint), {
        name: path_1.default.basename(entrypoint, "dart").replace("[", "_").replace("]", "_"),
        sdk: SDK_VERSION,
    });
    await fs_1.promises.writeFile(path_1.default.join(tmp, "pubspec.yaml"), makePubspec(pubspec), "utf-8");
    build_utils_1.debug("Downloading files");
    const downloadedFiles = await build_utils_1.download(files, workPath, meta);
    const entrypointFilePath = downloadedFiles[entrypoint].fsPath;
    const env = {
        ...process_1.default.env,
        TMP: tmp,
        DIST: distPath,
        BUILDER: __dirname,
        ENTRYPOINT: entrypoint,
        ENTRYPOINT_PATH: entrypointFilePath,
        VERCEL_DEV: meta.isDev ? "1" : "0",
    };
    build_utils_1.debug("Running `build.sh`");
    await execa_1.default(path_1.default.join(__dirname, "build.sh"), [], {
        env,
        cwd: workPath,
        stdio: "inherit",
        shell: "/bin/bash",
    });
    const extraFiles = await gatherExtraFiles(config.includeFiles, entrypointFilePath);
    const output = await build_utils_1.createLambda({
        files: { ...extraFiles, ...(await build_utils_1.glob("**", distPath)) },
        handler: "bootstrap",
        runtime: "provided",
    });
    return { output };
}
exports.build = build;
//# sourceMappingURL=index.js.map